@@ -33,9 +33,10 @@
 #  define KASTENGUI_DEPRECATED_NO_EXPORT KASTENGUI_NO_EXPORT KASTENGUI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KASTENGUI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KASTENGUI_NO_DEPRECATED
+#    define KASTENGUI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
